#' @importFrom madshapR as_data_dict_mlstr
madshapR::as_data_dict_mlstr

#' @importFrom madshapR as_taxonomy
madshapR::as_taxonomy

#' @importFrom madshapR as_valueType
madshapR::as_valueType

#' @importFrom madshapR as_category
madshapR::as_category

#' @importFrom madshapR is_category
madshapR::is_category

#' @importFrom madshapR data_extract
madshapR::data_extract

#' @importFrom madshapR dataset_zap_data_dict
madshapR::dataset_zap_data_dict

#' @importFrom madshapR is_data_dict_mlstr
madshapR::is_data_dict

#' @importFrom madshapR is_data_dict
madshapR::is_data_dict_mlstr

#' @importFrom madshapR is_dataset
madshapR::is_dataset

#' @importFrom madshapR is_dossier
madshapR::is_dossier

#' @importFrom madshapR is_taxonomy
madshapR::is_taxonomy

#' @importFrom madshapR valueType_adjust
madshapR::valueType_adjust

#' @importFrom madshapR valueType_self_adjust
madshapR::valueType_self_adjust

#' @importFrom madshapR col_id
madshapR::col_id

#' @importFrom madshapR data_dict_filter
madshapR::data_dict_filter

#' @importFrom madshapR data_dict_trim_labels
madshapR::data_dict_trim_labels

#' @importFrom madshapR data_dict_update
madshapR::data_dict_update

#' @importFrom madshapR has_categories
madshapR::has_categories

#' @importFrom madshapR first_label_get
madshapR::first_label_get

#' @importFrom madshapR data_dict_match_dataset
madshapR::data_dict_match_dataset

#' @importFrom madshapR as_dataset
#' @name as_dataset
#' @rdname as_dataset
#' @keywords imported
#' @export
madshapR::as_dataset

#' @importFrom madshapR as_dossier
#' @name as_dossier
#' @rdname as_dossier
#' @keywords imported
#' @export
madshapR::as_dossier

#' @importFrom madshapR bookdown_open
#' @name bookdown_open
#' @rdname bookdown_open
#' @keywords imported
#' @export
madshapR::bookdown_open

#' @importFrom madshapR data_dict_apply
#' @name data_dict_apply
#' @rdname data_dict_apply
#' @keywords imported
#' @export
madshapR::data_dict_apply

#' @importFrom madshapR data_dict_extract
#' @name data_dict_extract
#' @rdname data_dict_extract
#' @keywords imported
#' @export
madshapR::data_dict_extract

#' @importFrom madshapR as_data_dict
#' @name as_data_dict
#' @rdname as_data_dict
#' @keywords imported
#' @export
madshapR::as_data_dict

#' @importFrom madshapR dossier_create
#' @name dossier_create
#' @rdname dossier_create
#' @keywords imported
#' @export
madshapR::dossier_create

#' @importFrom madshapR dataset_evaluate
#' @name dataset_evaluate
#' @rdname dataset_evaluate
#' @keywords imported
#' @export
madshapR::dataset_evaluate

#' @importFrom madshapR data_dict_evaluate
#' @name data_dict_evaluate
#' @rdname data_dict_evaluate
#' @keywords imported
#' @export
madshapR::data_dict_evaluate

#' @importFrom madshapR dossier_evaluate
#' @name dossier_evaluate
#' @rdname dossier_evaluate
#' @keywords imported
#' @export
madshapR::dossier_evaluate

#' @importFrom madshapR dataset_summarize
#' @name dataset_summarize
#' @rdname dataset_summarize
#' @keywords imported
#' @export
madshapR::dataset_summarize

#' @importFrom madshapR dossier_summarize
#' @name dossier_summarize
#' @rdname dossier_summarize
#' @keywords imported
#' @export
madshapR::dossier_summarize

#' @importFrom madshapR dataset_visualize
#' @name dataset_visualize
#' @rdname dataset_visualize
#' @keywords imported
#' @export
madshapR::dataset_visualize











